==> libdap_3.5.3.orig.tar.gz: libdap-3.5.3.orig/GNU/GNURegex.h <==

// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of libdap, A C++ implementation of the OPeNDAP Data
// Access Protocol.

// Copyright (c) 2005 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

#ifndef _Regex_h
#define _Regex_h 1

#include <alloca.h>
#include <stdlib.h>
 
#include <sys/types.h>
#include <regex.h>

#include "Error.h"


/** a C++ interface to POSIX regular expression functions.

    @author James Gallagehr <jgallagher@opendap.org> */
class Regex
{
private:
    regex_t d_preg;
    void Regex::init(const char *t) throw(Error);
    
public:
    Regex(const char *t)  throw(Error);
    Regex(const char *t, int dummy)  throw(Error);
    ~Regex();

    /// Does the pattern match.
    int match(const char* s, int len, int pos = 0) const;
    /// How much of the string does the pattern matche.
    int search(const char* s, int len, int& matchlen, int pos = 0) const;
};

#endif

==> libdap_3.6.2.orig.tar.gz: libdap-3.6.2.orig/GNU/GNURegex.h <==

// -*- mode: c++; c-basic-offset:4 -*-

// This file is part of libdap, A C++ implementation of the OPeNDAP Data
// Access Protocol.

// Copyright (c) 2005 OPeNDAP, Inc.
// Author: James Gallagher <jgallagher@opendap.org>
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
// 
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.

#ifndef _Regex_h
#define _Regex_h 1

#ifndef WIN32
#include <alloca.h>
#endif
#include <stdlib.h>
 
#include <sys/types.h>
#include <regex.h>

#include "Error.h"


/** a C++ interface to POSIX regular expression functions.

    @author James Gallagehr <jgallagher@opendap.org> */
class Regex
{
private:
    regex_t d_preg;
    void init(const char *t) throw(Error);
    
public:
    Regex(const char *t)  throw(Error);
    Regex(const char *t, int dummy)  throw(Error);
    ~Regex();

    /// Does the pattern match.
    int match(const char* s, int len, int pos = 0) const;
    /// How much of the string does the pattern matche.
    int search(const char* s, int len, int& matchlen, int pos = 0) const;
};

#endif
